@@ -1,6 +1,6 @@
 plot.ibr <- function(x,...) {
   r <- residuals(x)
   yh <- predict(x)
-  plot(yh, r, xlab = "Index", ylab = "Residuals",...)
+  plot(yh, r, xlab = "Fitted", ylab = "Residuals",...)
   invisible()
 }
